==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System/System.Net.Configuration/FtpCachePolicyElement.cs <==
//
// System.Net.Configuration.HttpCachePolicyElement.cs
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && CONFIGURATION_DEP

using System;
using System.Configuration;
using System.Net.Cache;
using System.Xml;

namespace System.Net.Configuration 
{
	public sealed class FtpCachePolicyElement : ConfigurationElement
	{
		#region Fields

		static ConfigurationProperty policyLevelProp;
		static ConfigurationPropertyCollection properties;

		#endregion // Fields

		#region Constructors

		static FtpCachePolicyElement ()
		{
			policyLevelProp = new ConfigurationProperty ("policyLevel", typeof (RequestCacheLevel), RequestCacheLevel.Default);
			properties = new ConfigurationPropertyCollection ();

			properties.Add (policyLevelProp);
		}

		public FtpCachePolicyElement ()
		{
		}

		#endregion // Constructors

		#region Properties

		[ConfigurationProperty ("policyLevel", DefaultValue = "Default")]
		public RequestCacheLevel PolicyLevel {
			get { return (RequestCacheLevel) base [policyLevelProp]; }
			set { base [policyLevelProp] = value; }
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}

		#endregion // Properties

		#region Methods

		[MonoTODO]
		protected override void DeserializeElement (XmlReader reader, bool serializeCollectionKey)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		protected override void Reset (ConfigurationElement parentElement)
		{
			throw new NotImplementedException ();
		}

		#endregion // Methods
	}
}

#endif

==> mono-4.4.0.148.tar.bz2: mono-4.4.0/mcs/class/System/System.Net.Configuration/FtpCachePolicyElement.cs <==
//
// System.Net.Configuration.HttpCachePolicyElement.cs
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if CONFIGURATION_DEP

using System;
using System.Configuration;
using System.Net.Cache;
using System.Xml;

namespace System.Net.Configuration 
{
	public sealed class FtpCachePolicyElement : ConfigurationElement
	{
		#region Fields

		static ConfigurationProperty policyLevelProp;
		static ConfigurationPropertyCollection properties;

		#endregion // Fields

		#region Constructors

		static FtpCachePolicyElement ()
		{
			policyLevelProp = new ConfigurationProperty ("policyLevel", typeof (RequestCacheLevel), RequestCacheLevel.Default);
			properties = new ConfigurationPropertyCollection ();

			properties.Add (policyLevelProp);
		}

		public FtpCachePolicyElement ()
		{
		}

		#endregion // Constructors

		#region Properties

		[ConfigurationProperty ("policyLevel", DefaultValue = "Default")]
		public RequestCacheLevel PolicyLevel {
			get { return (RequestCacheLevel) base [policyLevelProp]; }
			set { base [policyLevelProp] = value; }
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}

		#endregion // Properties

		#region Methods

		[MonoTODO]
		protected override void DeserializeElement (XmlReader reader, bool serializeCollectionKey)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		protected override void Reset (ConfigurationElement parentElement)
		{
			throw new NotImplementedException ();
		}

		#endregion // Methods
	}
}

#endif
